# cnslab

`cnslab` is a Python library for cns lab.

## Installation

You can install `cnslab` via pip:




This README provides a brief overview of the library, installation instructions, usage examples, and information about the license.
